.. _trojanzoo.utils.data:

data
=====

.. currentmodule:: trojanzoo.utils.data

.. autoclass:: TensorListDataset
.. autofunction:: dataset_to_tensor
.. autofunction:: sample_batch
.. autofunction:: split_dataset
.. autofunction:: get_class_subset
